      * ----------------------------------------------------------------
      *  FUNC-REGISTRY-PUT----------- Write/update data in the Registry
      * 			      If key exists,
      * 				UPDATE the entry
      * 			      else
      * 				CREATE the entry.
      *
      *  FUNC-REGISTRY-GET----------- Get a value from the Registry
      *
      *  FUNC-REGISTRY-DELETE-VALUE-- Delete a value from the Registry
      *
      *  FUNC-REGISTRY-DELETE-SUBKEY- Delete a key and all descendants,
      * 			      including all subkeys and values
      * ----------------------------------------------------------------
      *
      *  The subkey you specify is automatically appended to the
      *  correct high-order key value, so the full key will be:
      *
      *  HKEY_CURRENT_USER\Software\Company\Application\Subkey
      *
      *  Note 1. Total length of this key must be LESS THAN 255 bytes,
      *
      *       2. You provided your company name and the name of your
      * 	 application when you opened your main/container panel.
      *
      *       3. You provide the subkey when you use this function.
      *
      *  Your data is stored beneath your key in name/data pairs.  You
      *  may have many named elements beneath your key.  For example,
      *  you can use the Windows program Regedit.exe to inspect the
      *  registry entries belonging to GUI ScreenIO.  Look under this
      *  key:
      *
      *  HKEY_CURRENT_USER\Software\Norcom\GUI ScreenIO Editor\Settings
      *
      *  Under this key, you will find several item:
      *
      *    Advanced    (hex values, stored as a BINARY type)
      *    Base        (hex values, stored as a BINARY type)
      *    CompanyName (Text, stored as a TEXT type)
      *
      *  ...and so on.	If you selected the option to save user
      *  preferences in your GUI ScreenIO application, GUI ScreenIO
      *  creates a GUI ScreenIO\Saved State subkey automatically.
      *  The names of the items are your panel names, and the panel
      *  state is stored as a binary item.
      * ----------------------------------------------------------------
      *
      *  The functions are all similar.  Here's how to save a value:
      *
      *      COPY WIN32API.
      *      COPY REGISTRY.
      *       .
      *       .
      * ------------------------: Specify the subkey value.
      *
      *    MOVE 'My Settings' TO REGISTRY-SUBKEY.
      *
      * ------------------------: Specify whether TEXT or BINARY data.
      *
      *    SET REGISTRY-DATA-IS-TEXT TO TRUE.
      *
      * ------------------------: Specify the value name and associated
      * 			: data to be stored.
      *
      *    MOVE 'Value 1'            TO REGISTRY-VALUENAME.
      *    MOVE 'Registry Text Data' TO REGISTRY-DATA.
      *
      * ------------------------: Call the API to update the registry.
      *
      *    SET FUNC-REGISTRY-PUT TO TRUE.
      *    CALL 'GS_WINAPI' USING WIN32API-PARMS
      * 			  REGISTRY-PARMS
      * 			  WIN32API-B
      * 			  WIN32API-C
      * 			  WIN32API-D
      * 			  WIN32API-E
      * 			  WIN32API-F.
      *
      * ------------------------: If function failed,
      * 			:   display a textual error message.
      *
      *    IF WIN32API-FAILED
      *      MOVE WIN32API-ERROR-TEXT TO my-error-message
      *      do whatever to display my-error-message.
      *
      * ----------------------------------------------------------------
      *
       01  REGISTRY-PARMS.
      * 			: Subkey.
      *
	   05  REGISTRY-SUBKEY		   PIC X(254).

      * 			: Your name for this data item.  You
      * 			: can store multiple data items under
      * 			: the same registry key...

	   05  REGISTRY-VALUENAME	   PIC X(32).

      * 			: Data associated with your key.
      * 			:
      * 			: Function | Use
      * 			: --------   ---------------------------
      * 			: PUT	     Value to store/update
      * 			: GET	     Value retrieved
      * 			: DELETE     Not used

	   05  REGISTRY-DATA		   PIC X(1023).

      * 			: Type of data.

	   05  REGISTRY-DATA-FORMAT	   PIC X.
	     88  REGISTRY-DATA-IS-TEXT	   VALUE LOW-VALUE.
	     88  REGISTRY-DATA-IS-BINARY   VALUE 'B'.

      * 			: Byte count.
      * 			: - Not used for TEXT
      * 			: - Required for BINARY data.
      * 			:
      * 			: Function | Use
      * 			: --------   ---------------------------
      * 			: PUT	     Number of bytes in DATA
      * 			: GET	     Bytes returned
      * 			: DELETE     Not used

	   05  REGISTRY-DATA-LENGTH	   PIC S9(9) COMP-5.
